import { EditorView, PluginValue, Tooltip, ViewUpdate } from "@codemirror/view";
import type { DefinitionResult, LanguageServerClient, Notification } from "../lsp/types.js";
import { CompletionContext, CompletionResult } from "@codemirror/autocomplete";
import { CompletionTriggerKind, PublishDiagnosticsParams } from "vscode-languageserver-protocol";
import type LSP from 'vscode-languageserver-protocol';
export type LSPContent = LSP.MarkupContent | LSP.MarkedString | LSP.MarkedString[];
export declare class LanguageServerPlugin implements PluginValue {
    client: LanguageServerClient;
    private documentUri;
    private languageId;
    private view;
    private allowHTMLContent;
    private renderMarkdown;
    private documentVersion;
    private onGoToDefinition?;
    constructor(client: LanguageServerClient, documentUri: string, languageId: string, view: EditorView, allowHTMLContent?: boolean, renderMarkdown?: (contents: LSPContent, allowHTML: boolean) => string, onGoToDefinition?: (result: DefinitionResult) => void);
    private changeSetToChangeEvents;
    update({ docChanged, startState, changes }: ViewUpdate): void;
    destroy(): void;
    initialize({ documentText }: {
        documentText: string;
    }): Promise<void>;
    sendChanges(changes: LSP.TextDocumentContentChangeEvent[]): Promise<void>;
    requestDiagnostics(view: EditorView): void;
    requestHoverTooltip(view: EditorView, { line, character }: {
        line: number;
        character: number;
    }): Promise<Tooltip | null>;
    requestCompletion(context: CompletionContext, { line, character }: {
        line: number;
        character: number;
    }, { triggerKind, triggerCharacter, }: {
        triggerKind: CompletionTriggerKind;
        triggerCharacter: string | undefined;
    }): Promise<CompletionResult | null>;
    requestDefinition(_view: EditorView, { line, character }: {
        line: number;
        character: number;
    }): Promise<DefinitionResult | undefined>;
    processNotification(notification: Notification): void;
    processDiagnostics(params: PublishDiagnosticsParams): Promise<void>;
    private requestCodeActions;
    requestRename(view: EditorView, { line, character }: {
        line: number;
        character: number;
    }): Promise<void>;
}
//# sourceMappingURL=plugin.d.ts.map